@@ -10,18 +10,17 @@
 ##' stamps for dates and times (MHS). These function might be useful when the
 ##' input template is unambiguous and matches both a time and a date format.
 ##'
-##' Lubridate tries it's best to figure our the formats, but often a given
-##' format can be interpreted in several ways. One way to deal with the
-##' situation is to provide unambiguous formats like 22/05/81 instead of
-##' 10/05/81 if you want d/m/y format. Another option is to use a more
-##' specialized stamp_date and stamp_time. The core function `stamp()` give
-##' priority to longer date-time formats.
+##' Lubridate tries hard to guess the formats, but often a given format can be
+##' interpreted in multiple ways. One way to deal with such cases is to provide
+##' unambiguous formats like 22/05/81 instead of 10/05/81 for d/m/y
+##' format. Another way is to use a more specialized [`stamp_date`] and
+##' [`stamp_time`]. The core function `stamp()` prioritizes longer date-time
+##' formats.
 ##'
-##' Another option is to provide a vector of several values as `x`
-##' parameter. Then \pkg{lubridate} will choose the format which fits `x` the
-##' best. Note that longer formats are preferred. If you have "22:23:00 PM" then
-##' "HMSp" format will be given priority to shorter "HMS" order which also fits
-##' the supplied string.
+##' If `x` is a vector of values \pkg{lubridate} will choose the format which
+##' "fits" `x` the best. Note that longer formats are preferred. If you have
+##' "22:23:00 PM" then "HMSp" format will be given priority to shorter "HMS"
+##' order which also fits the supplied string.
 ##'
 ##' Finally, you can give desired format order directly as `orders`
 ##' argument.
@@ -197,14 +196,15 @@ stamp <- function(x, orders = lubridate_formats,
 
 ##' @rdname stamp
 ##' @export
-stamp_date <- function(x, locale = Sys.getlocale("LC_TIME"))
+stamp_date <- function(x, locale = Sys.getlocale("LC_TIME"), quiet = FALSE)
   stamp(x, orders = c("ymd", "dmy", "mdy", "ydm", "dym", "myd", "my", "ym", "md", "dm", "m", "d", "y"),
-        locale = locale)
+        locale = locale, quiet = quiet)
 
 ##' @rdname stamp
 ##' @export
-stamp_time <- function(x, locale = Sys.getlocale("LC_TIME"))
-  stamp(x, orders = c("hms", "hm", "ms", "h", "m", "s"), locale = locale)
+stamp_time <- function(x, locale = Sys.getlocale("LC_TIME"), quiet = FALSE)
+  stamp(x, orders = c("hms", "hm", "ms", "h", "m", "s"),
+        locale = locale, quiet = quiet)
 
 
 lubridate_formats <- local({
